@@ -6,7 +6,7 @@ use warnings  qw(FATAL utf8);    # Fatalize encoding glitches.
 
 use Getopt::Long;
 
-use GraphViz2::Marpa::Utils;
+use GraphViz2::Marpa::Demo;
 
 use Pod::Usage;
 
@@ -25,7 +25,7 @@ if ($option_parser -> getoptions
 {
 	pod2usage(1) if ($option{'help'});
 
-	exit GraphViz2::Marpa::Utils -> new(%option) -> generate_demo_index;
+	exit GraphViz2::Marpa::Demo -> new(%option) -> generate_demo_index;
 }
 else
 {
